@@ -2,11 +2,11 @@ const toggle = (button) =>  {
     const passwordElement = document.getElementById(button.getAttribute('aria-controls'));
     if (passwordElement.type === "password") {
         passwordElement.type = "text";
-        button.children.item(0).classList.replace("fa-eye", "fa-eye-slash");
+        button.children.item(0).className = button.dataset.iconHide;
         button.setAttribute("aria-label", button.dataset.labelHide);
     } else if(passwordElement.type === "text") {
         passwordElement.type = "password";
-        button.children.item(0).classList.replace("fa-eye-slash", "fa-eye");
+        button.children.item(0).className = button.dataset.iconShow;
         button.setAttribute("aria-label", button.dataset.labelShow);
     }
 }
